@@ -1,7 +1,7 @@
 package App::td;
 
-our $DATE = '2016-06-26'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2017-01-01'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 #IFUNBUILT
@@ -112,6 +112,9 @@ Next, you can use these actions:
     # append an average row
     % list-files -l --json | td avg-row
 
+    # add a row number column (1, 2, 3, ...)
+    % list-files -l --json | td rownum-col
+
 _
     args => {
         action => {
@@ -126,6 +129,7 @@ _
                                             info
                                             rowcount
                                             rowcount-row
+                                            rownum-col
                                             select
                                             sort
                                             sum
@@ -260,6 +264,14 @@ sub td {
             last;
         }
 
+        if ($action eq 'rownum-col') {
+            $input_obj->add_col('_rownum', 0); # XXX if table already has that column, use _rownum2, ...
+            $input_obj->set_col_val(_rownum => sub { my %a = @_; $a{row_idx}+1 });
+            $output = [200, "OK", $input_obj->{data},
+                       {'table.fields' => $input_obj->{cols_by_idx}}];
+            last;
+        }
+
         if ($action =~ /\A(sum|sum-row|avg|avg-row)\z/) {
             require Scalar::Util;
             my $cols = $input_obj->cols_by_idx;
@@ -369,7 +381,7 @@ App::td - Manipulate table data
 
 =head1 VERSION
 
-This document describes version 0.07 of App::td (from Perl distribution App-td), released on 2016-06-26.
+This document describes version 0.08 of App::td (from Perl distribution App-td), released on 2016-01-01.
 
 =head1 FUNCTIONS
 
@@ -443,6 +455,9 @@ Next, you can use these actions:
  
  # append an average row
  % list-files -l --json | td avg-row
+ 
+ # add a row number column (1, 2, 3, ...)
+ % list-files -l --json | td rownum-col
 
 This function is not exported.
 
@@ -507,7 +522,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
